@@ -2,7 +2,7 @@
 
 #include <iostream>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 
 #include "diskcacheAPI/Cache/RegistrySingleton.hh"
 
@@ -19,9 +19,9 @@ namespace diskCache
     RegistrySingleton( )
       : Cache::Registry( )
     {
-      LDASTools::AL::AtExit::Append( singleton_suicide,
-				     "diskCache::Cache::RegistrySingleton",
-				     50 );
+      LDASTools::AL::MemChecker::Append( singleton_suicide,
+					 "diskCache::Cache::RegistrySingleton",
+					 50 );
     }
     /** \endcond */
 
