@@ -311,6 +311,7 @@ Verify( )
 
     check_for_duplicate_channel_names( true ),
     m_check_data_valid( false ),
+    m_check_data_valid_all( false ),
     m_check_expandability( true ),
     m_check_fast( false ),
     m_check_file_checksum( true ),
@@ -649,6 +650,8 @@ operator()( IFrameStream& Stream,
       //-----------------------------------------------------------------
       // Read through all objects
       //-----------------------------------------------------------------
+      std::ostringstream	dataValidAll;
+
       while( Stream.good( ) )
       {
 	if ( ( m_check_frame_checksum == true )
@@ -981,8 +984,16 @@ operator()( IFrameStream& Stream,
 	}
 	catch( const VerifyException& E )
 	{
-	  m_error_info << E.what( );
-	  return E.ErrorCode( );
+	  if ( ( E.ErrorCode( ) == VerifyException::DATA_INVALID )
+	       && ( CheckDataValidAll( ) ) )
+	  {
+	    dataValidAll << E.what( );
+	  }
+	  else
+	  {
+	    m_error_info << E.what( );
+	    return E.ErrorCode( );
+	  }
 	}
 	catch( const std::exception& e )
 	{
@@ -994,6 +1005,11 @@ operator()( IFrameStream& Stream,
 	  throw VerifyException( VerifyException::INVALID_FRAME_STRUCTURE );
 	}
       } // while freme_stream.good
+      if ( ! dataValidAll.str( ).empty( ) )
+      {
+	m_error_info << dataValidAll.str( );
+	return VerifyException::DATA_INVALID;
+      }
     } // if - Fast Checking
   }
   catch ( const VerifyException& E )
