@@ -34,6 +34,12 @@ using namespace FrameCPP::Compression;
 #define AT( )
 #endif
 
+#if HAVE_TEMPLATE_MOVE
+#define MOVE_RET(a) ( std::move( a ) )
+#else /* HAVE_TEMPLATE_MOVE */
+#define MOVE_RET(a) ( a )
+#endif /* HAVE_TEMPLATE_MOVE */
+
 //-----------------------------------------------------------------------
 // Local functions and variables
 //-----------------------------------------------------------------------
@@ -1233,7 +1239,7 @@ namespace FrameCPP
       //---------------------------------------------------------------------
       // Return the newly constructed FrVect
       //---------------------------------------------------------------------
-      return retval;
+      return MOVE_RET( retval );
     }
 
     //-----------------------------------------------------------------------
