@@ -146,6 +146,18 @@ public:
     m_data_valid = Value;
   }
 
+  inline bool
+  DataValidAll( )
+  {
+    return m_data_valid_all;
+  }
+
+  inline void
+  DataValidAll( bool Value )
+  {
+    m_data_valid_all = Value;
+  }
+
   inline bool
   DuplicateChannelNames( )
   {
@@ -236,9 +248,11 @@ private:
     OPT_CHECKSUM_FILE_ONLY,
     OPT_CHECKSUM_FRAMES,
     OPT_DATA_VALID,
+    OPT_DATA_VALID_ALL,
     OPT_DUPLICATE_CHANNEL_NAMES,
     OPT_FORCE,
     OPT_HELP,
+    OPT_METADATA_CHECK,
     OPT_METADATA_CHECK_NO,
     OPT_RELAX,
     OPT_RELAX_EOF_CHECKSUM,
@@ -251,6 +265,7 @@ private:
   bool		m_checksum_file_only;
   bool		m_checksum_frames;
   bool		m_data_valid;
+  bool		m_data_valid_all;
   bool		duplicate_channel_names;
   bool		m_force;
   bool		m_metadata_check;
@@ -267,6 +282,7 @@ CommandLine( int ArgC, char** ArgV )
     m_checksum_file_only( false ),
     m_checksum_frames( false ),
     m_data_valid( false ),
+    m_data_valid_all( false ),
     duplicate_channel_names( true ),
     m_force( false ),
     m_relax( false ),
@@ -349,6 +365,20 @@ CommandLine( int ArgC, char** ArgV )
 		 Option::ARG_NONE,
 		 desc.str( ) ) );
 
+  //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
+  desc.str( "" );
+  desc <<
+    "Check the dataValid bit in FrAdcData structures for non-zero values. This reports all channels with non-zero dataValid values."
+    " (Default: " << ( ( DataValidAll( ) )
+		       ? "all"
+		       : "first only" ) << " )"
+    ;
+  m_options.
+    Add( Option( OPT_DATA_VALID_ALL,
+		 "data-valid-all",
+		 Option::ARG_NONE,
+		 desc.str( ) ) );
+
   //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   desc.str( "" );
   desc <<
@@ -365,6 +395,20 @@ CommandLine( int ArgC, char** ArgV )
 		 "<bool>",
 		 new CommandLineOptions::ValidateBool( ) ) );
 
+  //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
+  desc.str( "" );
+  desc <<
+    "Enable the checking of the frame's meta data."
+    " (Default: " << ( ( MetadataCheck( ) )
+		       ? "check"
+		       : "no check" ) << " )"
+    ;
+  m_options.
+    Add( Option( OPT_METADATA_CHECK,
+		 "metadata-check",
+		 Option::ARG_NONE,
+		 desc.str( ) ) );
+
   //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   desc.str( "" );
   desc <<
@@ -531,6 +575,13 @@ CommandLine( int ArgC, char** ArgV )
       case OPT_CHECKSUM_FRAMES:
 	ChecksumFrames( true );
 	break;
+      case OPT_DATA_VALID:
+	DataValid( true );
+	break;
+      case OPT_DATA_VALID_ALL:
+	DataValid( true );
+	DataValidAll( true );
+	break;
       case OPT_DUPLICATE_CHANNEL_NAMES:
 	if ( arg_value.size( ) > 0 )
 	{
@@ -544,12 +595,15 @@ CommandLine( int ArgC, char** ArgV )
       case OPT_FORCE:
 	Force( true );
 	break;
-      case OPT_RELAX:
-	Relax( true );
+      case OPT_METADATA_CHECK:
+	MetadataCheck( true );
 	break;
       case OPT_METADATA_CHECK_NO:
 	MetadataCheck( false );
 	break;
+      case OPT_RELAX:
+	Relax( true );
+	break;
       case OPT_RELAX_EOF_CHECKSUM:
 	RelaxEOFChecksum( true );
 	break;
@@ -590,6 +644,7 @@ try
 
   verifier.CheckFrameChecksum( cl.ChecksumFrames( ) );
   verifier.CheckDataValid( cl.DataValid( ) );
+  verifier.CheckDataValidAll( cl.DataValidAll( ) );
   verifier.CheckForDuplicateChannelNames( cl.DuplicateChannelNames( ) );
   verifier.MustHaveEOFChecksum( cl.RelaxEOFChecksum( ) == false );
   verifier.Strict( cl.Relax( ) == false );
