@@ -34,7 +34,7 @@ typedef Common::FrameBuffer< filebuf > FrameBuffer;
 typedef Common::FrameH frameh_type;
 typedef SharedPtr< frameh_type > build_frame_type;
 
-static const INT_4U CHANNEL_COUNT = /* 64 */  32;
+static const INT_4U CHANNEL_COUNT = 64;
 static const LDASTools::AL::GPSTime START_TIME( 913423140, 0 );
 static const INT_2U ULEAPS = START_TIME.GetLeapSeconds( );
 static const REAL_8 DT = 60.0;
@@ -58,7 +58,7 @@ main( int argc, char* argv[] )
 
     for ( INT_4U
 	    count = 1;
-	  count <= 64;
+	  count <= CHANNEL_COUNT;
 	  count = 1 << ++power )
     {
       make_file( count );
