@@ -22,7 +22,7 @@
 #include "genericAPI/LogHTML.hh"
 #include "genericAPI/Logging.hh"
 #include "genericAPI/Stat.hh"
-#include "genericAPI/Symbols.hh"
+#include "genericAPI/LDASplatform.hh"
 #if 0
 #include "genericAPI/TclSymbolTable.hh"
 #endif /* 0 */
@@ -39,7 +39,7 @@ using LDASTools::AL::unordered_map;
 using LDASTools::System::ErrnoMessage;
 
 using namespace GenericAPI;
-using GenericAPI::LogHTML;
+using GenericAPI::Log::HTML;
 using LDASTools::AL::GPSTime;
 
 typedef unordered_map< std::string, const char* > site_container_type;
@@ -49,12 +49,12 @@ static const pthread_t main_thread = pthread_self( );
 //-----------------------------------------------------------------------
 /// \brief Format gif image appropriate for log entry
 //-----------------------------------------------------------------------
-static const std::string gif_html( LogHTML::message_type MT,
+static const std::string gif_html( HTML::message_type MT,
 				   const LDASTools::AL::GPSTime& TimeStamp );
 //-----------------------------------------------------------------------
 /// \brief Format gif information for legend section of web pages.
 //-----------------------------------------------------------------------
-static const std::string gif_legend( LogHTML::message_type MT );
+static const std::string gif_legend( HTML::message_type MT );
 
 #if DEPRICATED
 typedef struct addrinfo* addr_info_type;
@@ -69,264 +69,256 @@ static int manager_connect( );
 
 namespace GenericAPI
 {
-
-  LogHTML::
-  LogHTML( const std::string& BaseName )
-    : ::GenericAPI::Log::LDAS( BaseName )
+  namespace Log
   {
-  }
-
-  LogHTML* LogHTML::
-  Clone( const std::string& BaseName ) const
-  {
-    return new LogHTML( BaseName );
-  }
-
-  const char* LogHTML::
-  FileExtension( ) const
-  {
-    static const char* extension = ".html";
-
-    return extension;
-  }
-
-  std::string LogHTML::
-  FormatJobInfo( const std::string& JobInfo ) const
-  {
-    std::ostringstream	retval;
-
-    try
+    HTML::
+    HTML( const std::string& BaseName )
+      : ::GenericAPI::Log::LDAS( BaseName )
     {
-      //-----------------------------------------------------------------
-      // Create hyperlinks to job files.
-      //-----------------------------------------------------------------
-      Symbols::RUN_CODE::value_type	run_code;
-    
-      Symbols::RUN_CODE::Get( run_code );
-      if ( ( run_code.length( ) > 0 )
-	   && ( JobInfo.compare( 0, run_code.length( ), run_code ) == 0 ) )
-      {
-	int			jobid;
-	std::istringstream
-	  jobid_stream( JobInfo.substr( run_code.length( ) ) );
+    }
 
-	jobid_stream >> jobid;
-	if ( jobid_stream.eof( ) )
-	{
-	  //-------------------------------------------------------------
-	  // It matches the regex ^{run_code}\d+$
-	  //-------------------------------------------------------------
-	  Symbols::HTTP_URL::value_type	http_url;
+    HTML* HTML::
+    Clone( const std::string& BaseName ) const
+    {
+      return new HTML( BaseName );
+    }
+
+    const char* HTML::
+    FileExtension( ) const
+    {
+      static const char* extension = ".html";
+
+      return extension;
+    }
+
+    std::string HTML::
+    FormatJobInfo( const std::string& JobInfo ) const
+    {
+      std::ostringstream	retval;
+
+      try
+      {
+	//-----------------------------------------------------------------
+	// Create hyperlinks to job files.
+	//-----------------------------------------------------------------
+	const std::string	run_code( LDASplatform::RunCode( ) );
     
-	  Symbols::HTTP_URL::Get( http_url );
-	  retval << "<a href=\"" << http_url
+	if ( ( run_code.length( ) > 0 )
+	     && ( JobInfo.compare( 0, run_code.length( ), run_code ) == 0 ) )
+	{
+	  int			jobid;
+	  std::istringstream
+	    jobid_stream( JobInfo.substr( run_code.length( ) ) );
+
+	  jobid_stream >> jobid;
+	  if ( jobid_stream.eof( ) )
+	  {
+	    //-------------------------------------------------------------
+	    // It matches the regex ^{run_code}\d+$
+	    //-------------------------------------------------------------
+	    retval << "<a href=\"" << LDASplatform::HTTP_URL( )
 		   << "/" << run_code << "_" << ( jobid / 10000 )
 		   << "/" << JobInfo
 		   << "/user_command.html\">"
 		   << "<b><i>" << JobInfo
 		   << "</i></b></a>"
-	    ;
+	      ;
 	  
+	  }
 	}
       }
-    }
-    catch( ... )
-    {
-      retval.str( "" );
-    }
-    if ( retval.str( ).length( ) == 0 )
-    {
-      retval << "<b><i><font color=\"green\">" << JobInfo << "</font></i></b>";
+      catch( ... )
+      {
+	retval.str( "" );
+      }
+      if ( retval.str( ).length( ) == 0 )
+      {
+	retval << "<b><i><font color=\"green\">" << JobInfo << "</font></i></b>";
+      }
+
+      return retval.str( );
     }
 
-    return retval.str( );
-  }
-
-  void LogHTML::
-  Message( message_type MessageType, level_type Level,
-	   const std::string& Caller, const std::string& JobInfo,
-	   const std::string& Message )
-  {
+    void HTML::
+    Message( message_type MessageType, level_type Level,
+	     const std::string& Caller, const std::string& JobInfo,
+	     const std::string& Message )
+    {
 #if DEPRICATED
-    getaddrinfo_for_manager( );
+      getaddrinfo_for_manager( );
 #endif /* DEPRICATED */
-    //-------------------------------------------------------------------
-    // Verify that the message should be logged
-    //-------------------------------------------------------------------
-    //    if ( ShouldLog( MessageType, Level ) )
-    {
-      //-----------------------------------------------------------------
-      // OK, this message should be logged.
-      // Format the message for logging and then get it into the queue
-      //-----------------------------------------------------------------
-      std::ostringstream	msg;
-      LDASTools::AL::GPSTime		t;
+      //-------------------------------------------------------------------
+      // Verify that the message should be logged
+      //-------------------------------------------------------------------
+      //    if ( ShouldLog( MessageType, Level ) )
+      {
+	//-----------------------------------------------------------------
+	// OK, this message should be logged.
+	// Format the message for logging and then get it into the queue
+	//-----------------------------------------------------------------
+	std::ostringstream	msg;
+	LDASTools::AL::GPSTime		t;
 
-      t.Now( );
+	t.Now( );
 
-      msg
-	//---------------------------------------------------------------
-	// GIF image
-	//---------------------------------------------------------------
-	<< gif_html( MessageType, t )
-	//---------------------------------------------------------------
-	// Time stamp
-	//---------------------------------------------------------------
-	<< " <b>" << t.GetSeconds( ) << "</b>"
-	;
-      if ( *(JobInfo.begin( )) == '<' )
-      {
-	//---------------------------------------------------------------
-	// JobInfo has already been html formatted
-	//---------------------------------------------------------------
-	msg << " " << JobInfo;
-      }
-      else
-      {
-	//---------------------------------------------------------------
-	// JobInfo has not been formatted for HTML.
-	// Do only the very basic
-	//---------------------------------------------------------------
-	msg << " <b><i><font color=\"green\">" << JobInfo << "</font></i></b>";
-      }
-      //-----------------------------------------------------------------
-      msg
-	//---------------------------------------------------------------
-	// Caller
-	//---------------------------------------------------------------
-	<< " <b><i><font color=\"red\">" << Caller << "</font></i></b>"
-	//---------------------------------------------------------------
-	// Body of message
-	//---------------------------------------------------------------
-	<< " <tt>"
-	;
-      if ( Message.length( ) == 0 )
-      {
-	msg << "no message passed for logging";
-      }
-      else
-      {
-	//---------------------------------------------------------------
-	// Need to have temporary copy for mutations along the way
-	//---------------------------------------------------------------
-	std::string	body( Message );
-	// std::string	tmp_body;
-	//---------------------------------------------------------------
-	// As the final step, cleanup of whitespaces and non printable
-	// characters within body.
-	//---------------------------------------------------------------
-	bool ws = false;
-
-	for ( std::string::const_iterator
-		cur = body.begin( ),
-		last = body.end( );
-	      cur != last;
-	      ++cur )
-	{
-	  if ( isspace( *cur ) && ( ws == false ) )
-	  {
-	    msg << " ";
-	    ws = true;
-	    continue;
-	  }
-	  else if ( ! isprint( *cur ) )
-	  {
-	    msg << ".";
-	  }
-	  else
-	  {
-	    msg << *cur;
-	  }
-	  ws = false;
-	}
-	msg << "</tt>"
-	    << "<br>"
-	    << std::endl
+	msg
+	  //---------------------------------------------------------------
+	  // GIF image
+	  //---------------------------------------------------------------
+	  << gif_html( MessageType, t )
+	  //---------------------------------------------------------------
+	  // Time stamp
+	  //---------------------------------------------------------------
+	  << " <b>" << t.GetSeconds( ) << "</b>"
 	  ;
+	if ( *(JobInfo.begin( )) == '<' )
+	{
+	  //---------------------------------------------------------------
+	  // JobInfo has already been html formatted
+	  //---------------------------------------------------------------
+	  msg << " " << JobInfo;
+	}
+	else
+	{
+	  //---------------------------------------------------------------
+	  // JobInfo has not been formatted for HTML.
+	  // Do only the very basic
+	  //---------------------------------------------------------------
+	  msg << " <b><i><font color=\"green\">" << JobInfo << "</font></i></b>";
+	}
+	//-----------------------------------------------------------------
+	msg
+	  //---------------------------------------------------------------
+	  // Caller
+	  //---------------------------------------------------------------
+	  << " <b><i><font color=\"red\">" << Caller << "</font></i></b>"
+	  //---------------------------------------------------------------
+	  // Body of message
+	  //---------------------------------------------------------------
+	  << " <tt>"
+	  ;
+	if ( Message.length( ) == 0 )
+	{
+	  msg << "no message passed for logging";
+	}
+	else
+	{
+	  //---------------------------------------------------------------
+	  // Need to have temporary copy for mutations along the way
+	  //---------------------------------------------------------------
+	  std::string	body( Message );
+	  // std::string	tmp_body;
+	  //---------------------------------------------------------------
+	  // As the final step, cleanup of whitespaces and non printable
+	  // characters within body.
+	  //---------------------------------------------------------------
+	  bool ws = false;
+
+	  for ( std::string::const_iterator
+		  cur = body.begin( ),
+		  last = body.end( );
+		cur != last;
+		++cur )
+	  {
+	    if ( isspace( *cur ) && ( ws == false ) )
+	    {
+	      msg << " ";
+	      ws = true;
+	      continue;
+	    }
+	    else if ( ! isprint( *cur ) )
+	    {
+	      msg << ".";
+	    }
+	    else
+	    {
+	      msg << *cur;
+	    }
+	    ws = false;
+	  }
+	  msg << "</tt>"
+	      << "<br>"
+	      << std::endl
+	    ;
+	}
+	//-----------------------------------------------------------------
+	// Send the message to the queue
+	//-----------------------------------------------------------------
+	Log::Message( MessageType, Level, msg.str( ) );
       }
-      //-----------------------------------------------------------------
-      // Send the message to the queue
-      //-----------------------------------------------------------------
-      Log::Message( MessageType, Level, msg.str( ) );
     }
-  }
 
 #if DEPRICATEE
-  /// \cond ignore_legacy_ldas
-  void LogHTML::
-  TclInitialization( Tcl_Interp* Interp )
-  {
-    getaddrinfo_for_manager( );
-  }
-  /// \endcond
+    /// \cond ignore_legacy_ldas
+    void HTML::
+    TclInitialization( Tcl_Interp* Interp )
+    {
+      getaddrinfo_for_manager( );
+    }
+    /// \endcond
 #endif /* DEPRICATED */
 
-  void LogHTML::
-  html_header( )
-  {
-    //-------------------------------------------------------------------
-    // Gather information
-    //-------------------------------------------------------------------
-    const char* host = ( getenv( "HOST" ) )
-      ? getenv( "HOST" )
-      : "localhost";
+    void HTML::
+    html_header( )
+    {
+      //-------------------------------------------------------------------
+      // Gather information
+      //-------------------------------------------------------------------
+      const char* host = ( getenv( "HOST" ) )
+	? getenv( "HOST" )
+	: "localhost";
 
-    std::string	ldas_api;
-    Symbols::LDAS_SYSTEM::value_type	ldas_system_name;
+      //-------------------------------------------------------------------
+      // 
+      //-------------------------------------------------------------------
+      std::string site( siteInfoLookup( LDASplatform::LDASSystem( ) ) );
+      std::string special_log_header( "" );
 
-    APINameGet( ldas_api );
-    Symbols::LDAS_SYSTEM::Get( ldas_system_name );
+      std::string	title;
 
-    //-------------------------------------------------------------------
-    // 
-    //-------------------------------------------------------------------
-    std::string site( siteInfoLookup( ldas_system_name ) );
-    std::string special_log_header( "" );
-
-    std::string	title;
-
-    title = "The ";
-    title += ldas_api;
-    title += " API on ";
-    title += host;
-    title += " at ";
-    title += site;
+      title = "The ";
+      title += LDASplatform::AppName( );
+      title += " API on ";
+      title += host;
+      title += " at ";
+      title += site;
 
 
-    std::ostringstream	preamble;
-    preamble
-      << "<HTML> "
-      << "<HEAD> "
-      << "<TITLE>" << title << "</TITLE> "
-      << "<BODY BGCOLOR=\"#DDDDDD\" TEXT=\"#000000\"> "
-      << "<h3>" << title <<"</h3> "
-      << "<b><i>Legend:</i></b><br> "
-      << gif_legend( LogHTML::MT_GREEN ) << "<br> "
-      << gif_legend( LogHTML::MT_YELLOW ) << "<br> "
-      << gif_legend( LogHTML::MT_ORANGE ) << "<br> "
-      << gif_legend( LogHTML::MT_RED ) << "<br> "
-      << gif_legend( LogHTML::MT_BLUE ) << "<br> "
-      << gif_legend( LogHTML::MT_PURPLE ) << "<br> "
-      << gif_legend( LogHTML::MT_MAIL ) << "<br> "
-      << gif_legend( LogHTML::MT_PHONE )
-      << "<p>" << special_log_header
-      << "<p><b><i>Link:</i></b> "
-      << "<a href=\"APIstatus.html\">API Status Page for " << site << "</a> "
-      << "<p>" << std::endl
-      ;
-    writeDirect( preamble.str( ) );
-  }
+      std::ostringstream	preamble;
+      preamble
+	<< "<HTML> "
+	<< "<HEAD> "
+	<< "<TITLE>" << title << "</TITLE> "
+	<< "<BODY BGCOLOR=\"#DDDDDD\" TEXT=\"#000000\"> "
+	<< "<h3>" << title <<"</h3> "
+	<< "<b><i>Legend:</i></b><br> "
+	<< gif_legend( HTML::MT_GREEN ) << "<br> "
+	<< gif_legend( HTML::MT_YELLOW ) << "<br> "
+	<< gif_legend( HTML::MT_ORANGE ) << "<br> "
+	<< gif_legend( HTML::MT_RED ) << "<br> "
+	<< gif_legend( HTML::MT_BLUE ) << "<br> "
+	<< gif_legend( HTML::MT_PURPLE ) << "<br> "
+	<< gif_legend( HTML::MT_MAIL ) << "<br> "
+	<< gif_legend( HTML::MT_PHONE )
+	<< "<p>" << special_log_header
+	<< "<p><b><i>Link:</i></b> "
+	<< "<a href=\"APIstatus.html\">API Status Page for " << site << "</a> "
+	<< "<p>" << std::endl
+	;
+      writeDirect( preamble.str( ) );
+    }
 
 
-  void LogHTML::
-  html_trailer( )
-  {
-    std::ostringstream	postamble;
+    void HTML::
+    html_trailer( )
+    {
+      std::ostringstream	postamble;
 
-    postamble << "</BODY> </HTML>" << std::endl;
-    writeDirect( postamble.str( ) );
-  }
-}
+      postamble << "</BODY> </HTML>" << std::endl;
+      writeDirect( postamble.str( ) );
+    }
+  } // namespace - Log
+} // namespace GenericAPI
 
 //=======================================================================
 // Local members
@@ -350,7 +342,7 @@ struct gif_info
 // 
 //-----------------------------------------------------------------------
 const gif_info&
-gif_lookup( LogHTML::message_type MT )
+gif_lookup( HTML::message_type MT )
 {
   //---------------------------------------------------------------------
   // 
@@ -451,15 +443,15 @@ gif_lookup( LogHTML::message_type MT )
 	}
       };
 
-      gifs[ LogHTML::MT_OK ] = &gif_info_table[ 0 ];
-      gifs[ LogHTML::MT_WARN ] = &gif_info_table[ 1 ];
-      gifs[ LogHTML::MT_ERROR ] = &gif_info_table[ 2 ];
-      gifs[ LogHTML::MT_EMAIL ] = &gif_info_table[ 3 ];
-      gifs[ LogHTML::MT_CERTMAIL ] = &gif_info_table[ 4 ];
-      gifs[ LogHTML::MT_PHONE ] = &gif_info_table[ 5 ];
-      gifs[ LogHTML::MT_DEBUG ] = &gif_info_table[ 6 ];
-      gifs[ LogHTML::MT_NOTE ] = &gif_info_table[ 7 ];
-      gifs[ LogHTML::MT_ORANGE ] = &gif_info_table[ 8 ];
+      gifs[ HTML::MT_OK ] = &gif_info_table[ 0 ];
+      gifs[ HTML::MT_WARN ] = &gif_info_table[ 1 ];
+      gifs[ HTML::MT_ERROR ] = &gif_info_table[ 2 ];
+      gifs[ HTML::MT_EMAIL ] = &gif_info_table[ 3 ];
+      gifs[ HTML::MT_CERTMAIL ] = &gif_info_table[ 4 ];
+      gifs[ HTML::MT_PHONE ] = &gif_info_table[ 5 ];
+      gifs[ HTML::MT_DEBUG ] = &gif_info_table[ 6 ];
+      gifs[ HTML::MT_NOTE ] = &gif_info_table[ 7 ];
+      gifs[ HTML::MT_ORANGE ] = &gif_info_table[ 8 ];
 
       initialized = true;
     }
@@ -475,7 +467,7 @@ gif_lookup( LogHTML::message_type MT )
 //-----------------------------------------------------------------------
 //-----------------------------------------------------------------------
 static const std::string
-gif_legend( LogHTML::message_type MT )
+gif_legend( HTML::message_type MT )
 {
   std::ostringstream	desc;
 
@@ -499,7 +491,7 @@ gif_legend( LogHTML::message_type MT )
 }
 
 static const std::string
-gif_html( LogHTML::message_type MT,
+gif_html( HTML::message_type MT,
 	  const LDASTools::AL::GPSTime& TimeStamp )
 {
   std::ostringstream	gif;
@@ -513,12 +505,7 @@ gif_html( LogHTML::message_type MT,
     {
     case gif_info::ALT_EMAIL:
       {
-	std::string api;
-	std::string notify;
-
-	GenericAPI::APINameGet( api );
-	GenericAPI::EMailNotifyGet( api, notify );
-	alt << notify;
+	alt << LoggingInfo::EMailNotify( LDASplatform::AppName( ) );
       }
       break;
     case gif_info::ALT_TIME:
