@@ -23,7 +23,13 @@ namespace GenericAPI
 
       ::getrusage( RUSAGE_SELF, &usage );
 
-      AddDataPoint( Frequency, usage.ru_maxrss );
+      if ( flag | MEMORY_PHYSICAL )
+      {
+	//---------------------------------------------------------------
+	// Track the amount of physical RAM being used by process
+	//---------------------------------------------------------------
+        AddDataPoint( Frequency, usage.ru_maxrss );
+      }
     }
   }
 }
