@@ -46,8 +46,7 @@ namespace GenericAPI
 {
   StatPool::
   StatPool( )
-    : m_user_init_cb( NULL ),
-      m_initialized( false )
+    : m_user_init_cb( NULL )
   {
   }
 
