@@ -1,18 +1,18 @@
 #include <memory>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 
 #include "genericAPI/SymbolMapper.hh"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 
 static GenericAPI::SymbolMapper* init( )
 {
   using namespace GenericAPI;
 
-  AtExit::Append( SymbolMapper::OnExit,
-		  "GenericAPI::SymbolMapper::OnExit",
-			   5 );
+  MemChecker::Append( SymbolMapper::OnExit,
+		      "GenericAPI::SymbolMapper::OnExit",
+		      5 );
   return (SymbolMapper*)NULL;
 }
 
