@@ -18,7 +18,6 @@ using LDASTools::AL::MemChecker;
 using LDASTools::System::ErrnoMessage;
 
 static const int OFFLOAD_CPU_FOR_N_SECONDS = 1;
-static const int DEFAULT_BYTES_MAX   = 0;
 static const int DEFAULT_ENTRIES_MAX = 0;
 static const int WAIT_FOR_N_SECONDS = 5;
 
@@ -507,9 +506,6 @@ namespace LDASTools
     Log( const std::string& BaseName )
       : stream_delete_on_destruct( true ),
 	m_base_name( BaseName ),
-	m_bytes( 0 ),
-	m_bytes_max( DEFAULT_BYTES_MAX ),
-	m_entries( 0 ),
 	m_entries_max( DEFAULT_ENTRIES_MAX )
     {
       //-----------------------------------------------------------------
