@@ -285,13 +285,18 @@ namespace
     inline bool
     IsExiting( ) const
     {
+      bool retval = is_exiting;
+      if ( retval == false )
+      {
 #if EXITING_LOCK
-      ReadWriteLock	l( is_exiting_baton,
+	ReadWriteLock	l( is_exiting_baton,
 			   ReadWriteLock::READ,
 			   __FILE__, __LINE__ );
 #endif /* EXIING_LOCK */
 
-      return is_exiting;
+	return retval;
+      }
+      return retval;
     }
 
     inline bool
