@@ -12,7 +12,7 @@ namespace LDASTools
     //-------------------------------------------------------------------
     SystemCallTask::
     SystemCallTask( )
-      : Task( TaskThread::CANCEL_SIGNAL_ABANDON )
+      : Task( Thread::CANCEL_ABANDON )
     {
     }
 
