@@ -12,6 +12,7 @@
 #include <unistd.h>
 
 #include <cmath>
+#include <cstdlib>
 
 #include <fstream>
 #include <iomanip>
@@ -194,10 +195,13 @@ namespace {
 
 	static offset_table_type		m_offset_table;
 	static ReadWriteLock::baton_type	m_offset_table_lock;
+        static ReadWriteLock::baton_type        m_offset_table_env_lock;
 	static std::string			m_offset_table_filename;
 	static time_t				m_offset_table_time_check;
 	static time_t				m_offset_table_modify_time;
+        static bool                             m_offset_table_env_checked;
 
+        static void update_table_filename_from_env( );
 	static void update_table( );
 	static void update_table( std::istream& Stream );
     };
@@ -262,6 +266,8 @@ namespace LDASTools
 {
     namespace AL
     {
+	//---------------------------------------------------------------
+	//---------------------------------------------------------------
 	const GPSTime::unit_type GPSTime::DEFAULT_TIME_UNIT_TYPE = GPSTime::GPS;
 
 	GPSTime GPSTime::
@@ -529,10 +535,14 @@ namespace {
     ReadWriteLock::baton_type
       offset_data_type::m_offset_table_lock
         = ReadWriteLock::Baton( );
+    ReadWriteLock::baton_type
+      offset_data_type::m_offset_table_env_lock
+        = ReadWriteLock::Baton( );
 
     std::string		offset_data_type::m_offset_table_filename;
     time_t		offset_data_type::m_offset_table_time_check = 0;
     time_t		offset_data_type::m_offset_table_modify_time = 0;
+    bool                offset_data_type::m_offset_table_env_checked = false;
 
     INT_2U offset_data_type::
     GetLeapSeconds( const INT_4U TAI )
@@ -581,17 +591,40 @@ namespace {
 	}
     }
 
-    void offset_data_type::
+    inline void offset_data_type:: 
+    update_table_filename_from_env( )
+    {
+        const static std::string LEAPSECOND_ENV_KEY("GPS_LEAPSECOND_FILE");
+
+        ReadWriteLock
+            lock( m_offset_table_env_lock, ReadWriteLock::WRITE,
+                  __FILE__, __LINE__ );
+
+        if ( ( m_offset_table_env_checked == false ) &&
+	     ( m_offset_table_filename.length( ) == 0 ) &&
+             ( std::getenv(LEAPSECOND_ENV_KEY.c_str( ) ) != 0 ) )
+        { 
+            OffsetTableFilename( std::string( std::getenv( LEAPSECOND_ENV_KEY.c_str( ) ) ) );
+            m_offset_table_env_checked = true;
+        }
+    }
+
+    inline void offset_data_type::
     update_table( )
     {
 	time_t	now;
 
 	struct timeval now_buffer;
 
+	//---------------------------------------------------------------
+	// Find out what time it currently is
+	//---------------------------------------------------------------
 	gettimeofday( &now_buffer, 0 );
 
 	now = now_buffer.tv_sec;
 
+        update_table_filename_from_env( );	// Find out if env set
+
 	if ( ( m_offset_table_filename.length( ) > 0 ) &&
 	     ( now > m_offset_table_time_check ) )
 	{
@@ -628,6 +661,9 @@ namespace {
 	    {
 		m_offset_table_modify_time = stat_buffer.st_mtime;
 	    }
+	    //-----------------------------------------------------------
+	    // Check again in 7 days
+	    //-----------------------------------------------------------
 	    m_offset_table_time_check = now + ( SECONDS_PER_DAY * 7 );
 	}
 	else if ( m_offset_table.size( ) == 0 )
@@ -651,7 +687,7 @@ namespace {
 	}
     }
 
-    void offset_data_type::
+    inline void offset_data_type::
     update_table( std::istream& Stream )
     {
 	offset_table_type	tmp_table;
